
package ru.yandex.autotests.direct.fakebsproxy.beans.moderate;

import com.google.gson.annotations.SerializedName;
import ru.yandex.autotests.direct.fakebsproxy.beans.BaseBean;
import ru.yandex.autotests.direct.fakebsproxy.beans.moderate.enums.ModerationObjectTypeEnum;

public class Result extends BaseBean<Result> {

    @SerializedName("type")
    private ModerationObjectTypeEnum type;
    @SerializedName("id")
    private Long id;
    @SerializedName("cid")
    private Long cid;
    @SerializedName("pid")
    private Long pid;
    @SerializedName("bid")
    private Long bid;
    @SerializedName("object_id")
    private Long objectId;
    @SerializedName("content_id")
    private Long contentId;
    @SerializedName("callout_id")
    private Long calloutId;
    @SerializedName("statusModerate")
    private String statusModerate;
    @SerializedName("statusPostModerate")
    private String statusPostModerate;
    @SerializedName("errors")
    private Object errors;

    public Long getBid() {
        return bid;
    }

    public void setBid(Long bid) {
        this.bid = bid;
    }

    public Result withBid(Long bid) {
        this.bid = bid;
        return this;
    }

    public Object getErrors() {
        return errors;
    }

    public void setErrors(Object errors) {
        this.errors = errors;
    }

    public Result withErrors(Object errors) {
        this.errors = errors;
        return this;
    }

    public String getStatusModerate() {
        return statusModerate;
    }

    public void setStatusModerate(String statusModerate) {
        this.statusModerate = statusModerate;
    }

    public Result withStatusModerate(String statusModerate) {
        this.statusModerate = statusModerate;
        return this;
    }

    public String getStatusPostModerate() {
        return statusPostModerate;
    }

    public void setStatusPostModerate(String statusPostModerate) {
        this.statusPostModerate = statusPostModerate;
    }

    public Result withStatusPostModerate(String statusPostModerate) {
        this.statusPostModerate = statusPostModerate;
        return this;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Result withId(Long id) {
        this.id = id;
        return this;
    }

    public ModerationObjectTypeEnum getType() {
        return type;
    }

    public void setType(ModerationObjectTypeEnum type) {
        this.type = type;
    }

    public Result withType(ModerationObjectTypeEnum type) {
        this.type = type;
        return this;
    }

    public Long getObjectId() {
        return objectId;
    }

    public void setObjectId(Long objectId) {
        this.objectId = objectId;
    }

    public Result withObjectId(Long objectId) {
        this.objectId = objectId;
        return this;
    }

    public Long getCid() {
        return cid;
    }

    public void setCid(Long cid) {
        this.cid = cid;
    }

    public Result withCid(Long cid) {
        this.cid = cid;
        return this;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Result withPid(Long pid) {
        this.pid = pid;
        return this;
    }

    public Long getContentId() {
        return contentId;
    }

    public void setContentId(Long contentId) {
        this.contentId = contentId;
    }

    public Result withContentId(Long contentId) {
        this.contentId = contentId;
        return this;
    }

    public Long getCalloutId() {
        return calloutId;
    }

    public void setCalloutId(Long calloutId) {
        this.calloutId = calloutId;
    }

    public Result withCalloutId(Long calloutId) {
        this.calloutId = calloutId;
        return this;
    }
}
